@@ -52,7 +52,7 @@ fn run() -> Result<i32> {
         match argc_cmd {
             "--argc-eval" => match run_eval(runtime, args) {
                 Ok(output) => {
-                    println!("{}", output);
+                    println!("{output}");
                 }
                 Err(err) => {
                     println!(
@@ -83,7 +83,7 @@ fn run() -> Result<i32> {
                 let cwd = if is_runner_script(&script_path) {
                     if let Some(cwd) = runtime.current_dir() {
                         if env::var("ARGC_PWD").is_err() {
-                            envs.insert("ARGC_PWD".to_string(), escape_shell_words(&cwd));
+                            envs.insert("ARGC_PWD".to_string(), cwd);
                         }
                     }
                     Some(script_dir.as_path())
@@ -122,7 +122,7 @@ fn run() -> Result<i32> {
                         })?;
                     }
                 } else {
-                    print!("{}", script);
+                    print!("{script}");
                 }
             }
             "--argc-mangen" => {
@@ -144,7 +144,7 @@ fn run() -> Result<i32> {
                 };
                 let commands = [vec!["argc".to_string()], args[3..].to_vec()].concat();
                 let script = argc::generate_completions(shell, &commands);
-                print!("{}", script);
+                print!("{script}");
             }
             "--argc-compgen" => {
                 run_compgen(runtime, args.to_vec());
@@ -172,7 +172,7 @@ fn run() -> Result<i32> {
             }
             "--argc-shell-path" => {
                 let shell = runtime.shell_path()?;
-                println!("{}", shell);
+                println!("{shell}");
             }
             "--argc-help" => {
                 println!("{}", get_argc_help(runtime)?)
@@ -192,7 +192,7 @@ fn run() -> Result<i32> {
         let mut envs = HashMap::new();
         if let Some(cwd) = runtime.current_dir() {
             if env::var("ARGC_PWD").is_err() {
-                envs.insert("ARGC_PWD".to_string(), escape_shell_words(&cwd));
+                envs.insert("ARGC_PWD".to_string(), cwd);
             }
         }
         let script_file = script_file.display().to_string();
@@ -433,7 +433,7 @@ fn parse_script_args(args: &[String]) -> Result<(String, String, Vec<String>)> {
     let script_file = normalize_script_path(script_file);
     let args: Vec<String> = args[1..].to_vec();
     let source = fs::read_to_string(&script_file)
-        .with_context(|| format!("Failed to load script at '{}'", script_file))?;
+        .with_context(|| format!("Failed to load script at '{script_file}'"))?;
     let name = get_script_name(&script_file)?;
     let name = name.strip_suffix(".sh").unwrap_or(name);
     let mut cmd_args = vec![name.to_string()];
