@@ -30,7 +30,6 @@ fn render_manpage(cmd: &Command, section: &str) -> String {
     render_subcommands_section(&mut roff, cmd, section);
     render_envs_section(&mut roff, cmd);
     render_version_section(&mut roff, cmd);
-    render_author_section(&mut roff, cmd);
     roff.to_roff()
 }
 
@@ -155,7 +154,7 @@ fn render_subcommands_section(roff: &mut Roff, cmd: &Command, section: &str) {
     for subcmd in &cmd.subcommands {
         roff.control("TP", []);
         let name = subcmd.full_name();
-        roff.text([roman(format!("{}({})", name, section))]);
+        roff.text([roman(format!("{name}({section})"))]);
         for line in subcmd.describe.lines() {
             roff.text([roman(line)]);
         }
@@ -196,13 +195,6 @@ fn render_version_section(roff: &mut Roff, cmd: &Command) {
     }
 }
 
-fn render_author_section(roff: &mut Roff, cmd: &Command) {
-    if let Some(author) = &cmd.author {
-        roff.control("SH", ["AUTHORS"]);
-        roff.text([roman(author)]);
-    }
-}
-
 fn render_describe(body: &mut Vec<Inline>, describe: &str) {
     for line in describe.split('\n') {
         body.push(Inline::LineBreak);
