@@ -1,4 +1,4 @@
-use convert_case::{Boundary, Converter, Pattern};
+use convert_case::{Boundary, Converter};
 
 pub const VARIABLE_PREFIX: &str = "argc_";
 pub const BEFORE_HOOK: &str = "_argc_before";
@@ -7,7 +7,6 @@ pub const ROOT_NAME: &str = "prog";
 pub const MAIN_NAME: &str = "main";
 
 pub(crate) const META_VERSION: &str = "version";
-pub(crate) const META_AUTHOR: &str = "author";
 pub(crate) const META_DOTENV: &str = "dotenv";
 pub(crate) const META_DEFAULT_SUBCOMMAND: &str = "default-subcommand";
 pub(crate) const META_INHERIT_FLAG_OPTIONS: &str = "inherit-flag-options";
@@ -52,9 +51,13 @@ pub const ARGC_LOAD_DOTENV: &str = r#"_argc_load_dotenv() {
 
 pub fn to_cobol_case(value: &str) -> String {
     Converter::new()
-        .set_pattern(Pattern::Uppercase)
+        .set_pattern(convert_case::pattern::uppercase)
         .set_delim("-")
-        .set_boundaries(&[Boundary::Underscore, Boundary::LowerUpper, Boundary::Hyphen])
+        .set_boundaries(&[
+            Boundary::UNDERSCORE,
+            Boundary::LOWER_UPPER,
+            Boundary::HYPHEN,
+        ])
         .convert(value)
 }
 
