@@ -819,6 +819,16 @@ _choice_fn() {
     snapshot_compgen!(script, [vec!["prog", ""], vec!["prog", "abc", ""]]);
 }
 
+#[test]
+fn auto_alias_subcommand() {
+    let script = r###"
+# @cmd
+cmd_a() { :; }
+"###;
+
+    snapshot_compgen!(script, [vec!["prog", ""], vec!["prog", "cmd"]]);
+}
+
 #[test]
 fn multi_char() {
     let script = r#"
